@@ -56,7 +56,6 @@ typedef struct {
 	unsigned int draining:1;
 	unsigned int xrun_detected:1;
 	unsigned int hw_params_changed:1;
-	unsigned int active:1;
 	unsigned int negotiated:1;
 
 	snd_pcm_uframes_t hw_ptr;
@@ -94,6 +93,7 @@ static int update_active(snd_pcm_ioplug_t *io)
 	snd_pcm_pipewire_t *pw = io->private_data;
 	snd_pcm_sframes_t avail;
 	bool active;
+	uint64_t val;
 
 	avail = snd_pcm_ioplug_avail(io, pw->hw_ptr, io->appl_ptr);
 
@@ -112,20 +112,17 @@ static int update_active(snd_pcm_ioplug_t *io)
 	else {
 		active = false;
 	}
-	if (pw->active != active) {
-		uint64_t val;
 
-		pw_log_trace("%p: avail:%lu min-avail:%lu state:%s hw:%lu appl:%lu active:%d->%d state:%s",
-			pw, avail, pw->min_avail, snd_pcm_state_name(io->state),
-			pw->hw_ptr, io->appl_ptr, pw->active, active,
-			snd_pcm_state_name(io->state));
+	pw_log_trace("%p: avail:%lu min-avail:%lu state:%s hw:%lu appl:%lu active:%d state:%s",
+		pw, avail, pw->min_avail, snd_pcm_state_name(io->state),
+		pw->hw_ptr, io->appl_ptr, active,
+		snd_pcm_state_name(io->state));
+
+	if (active)
+		spa_system_eventfd_write(pw->system, io->poll_fd, 1);
+	else
+		spa_system_eventfd_read(pw->system, io->poll_fd, &val);
 
-		pw->active = active;
-		if (active)
-			spa_system_eventfd_write(pw->system, io->poll_fd, 1);
-		else
-			spa_system_eventfd_read(pw->system, io->poll_fd, &val);
-	}
 	return active;
 }
 
